@@ -1555,6 +1555,29 @@ fft_size_multiplier = 0
 # and should be about 5 to 10 Hertz.  Higher rates require more processor power.
 graph_refresh = 7
 
+## start_cw_delay			Start CW delay msec, integer
+# Quisk generates its own CW waveform when keyed by the serial port or MIDI.  Quisk delays this CW waveform
+# so that when changing from Rx to Tx there is time for relays to switch and power amps to turn on.
+# The CW key timing is preserved.  This is the delay in milliseconds from the first
+# CW key press until RF output. The delay can be zero to 250 milliseconds.
+# If the key is attached to the hardware and the hardware generates the CW, Quisk can not implement this delay.
+# Changes are immediate (no need to restart).
+start_cw_delay = 15
+
+## start_ssb_delay			Start SSB delay msec, integer
+# This discards the first few milliseconds of RF output when starting a transmission
+# so that relays can switch and power amps can turn on.
+# It operates in all modes except CW.
+# It should be long enough to allow filters to fill with samples.
+# Changes are immediate (no need to restart).
+start_ssb_delay = 100
+
+## maximum_tx_secs			Maximum Tx seconds, integer
+# This changes Quisk from transmit to receive after the specified number of seconds.
+# It is meant to be a failsafe timer in case Quisk is controlled remotely by another program and the link fails.
+# Enter zero to turn off the failsafe timer. If Quisk receives another Tx command, the timer restarts.
+# Changes are immediate (no need to restart).
+maximum_tx_secs = 0
 
 ## keyupDelay			Keyup delay msecs, integer
 # This is the key hang time for semi-breakin CW. It is the time in milliseconds
@@ -1677,7 +1700,7 @@ freedv_tx_msg = ''
 # This is the list of FreeDV modes and their index number.  The starting mode is the first listed.
 freedv_modes = (('Mode 1600', 0), 
 		('Mode 2400A', 3), ('Mode 2400B', 4), ('Mode 800XA', 5),
-		('Mode 700C', 6), ('Mode 700D', 7), ('Mode 2020', 8), ('Future9', 9), ('Future 10', 10))
+		('Mode 700C', 6), ('Mode 700D', 7), ('Mode 2020', 8), ('Mode 700E', 13))
 
 # These are the filter bandwidths for each mode.  Quisk has built-in optimized filters
 # for these values, but you can change them if you want.
